@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 13374 2022-01-15 07:17:59Z Lavender $
+# $Id: __init__.py 13415 2022-04-13 06:21:20Z Jason $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2022-01-15 15:17:59 +0800 (週六, 15 一月 2022) $
-# $Revision: 13374 $
+# $Author: Jason $ (last)
+# $Date: 2022-04-13 14:21:20 +0800 (Wed, 13 Apr 2022) $
+# $Revision: 13415 $
 
 from __future__ import print_function
 
@@ -655,7 +655,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
         'DIRS': [os.path.join(settingsDict.get('BASE_DIR', projectPath),
                               'templates'),],
-        # 需要這個才能找到 site-packages 裡面的 templates
+        # ݭnoӤ~ site-packages ̭ templates
         'APP_DIRS': True,
         'OPTIONS': {
             'context_processors': [
@@ -706,7 +706,17 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     update(settingsDict, authPasswordValidators)
     #=========================================================================
-
+    
+    #=========================================================================
+    #  Security
+    #  Ref: https://chipcullen.com/django-3-referrer-policy-change/
+    secureFeferrerPolicy = {
+        'SECURE_REFERRER_POLICY': 'no-referrer-when-downgrade'
+    }
+    
+    update(settingsDict, secureFeferrerPolicy)
+    #=========================================================================
+    
     #=========================================================================
     # Django plugins.
     middleware = [
