@@ -28,7 +28,8 @@ if (( $(crontab -l | grep -c "{{ hchk }}" ) == 0 )) ; then
     if (( $(crontab -l | grep -c "APP_NAME=" ) == 0 )) ; then
         env >> _cron
     fi
-    echo "{{ time }} $PWD/cron/Crontask.sh -i {{ hchk }} -l $HOME/app/log/ null null cmd "\""$PWD/cron/{{ jobName }}"\""" >> _cron
+    mkdir -p $HOME/app/log/{{ jobName }}/
+    echo "{{ time }} $PWD/cron/Crontask.sh -i {{ hchk }} -l $HOME/app/log/{{ jobName }}/ null null cmd "\""$PWD/cron/{{ jobName }}"\""" >> _cron
     if crontab _cron; then
         rm -rf _cron
     else
