@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13441 2022-05-04 04:19:40Z Jason $
+# $Id: Backends.py 13458 2022-05-11 05:12:53Z Jason $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Jason $
-# $Date: 2022-05-04 12:19:40 +0800 (Wed, 04 May 2022) $
-# $Revision: 13441 $
+# $Date: 2022-05-11 13:12:53 +0800 (Wed, 11 May 2022) $
+# $Revision: 13458 $
 
 import re
 import json
@@ -25,6 +25,8 @@ from django.conf import settings
 from django.core.exceptions import PermissionDenied
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
+from django.dispatch import Signal
+
 DEFAULT_TRAC_AUTH_URL = getattr(settings,
     'DEFAULT_TRAC_AUTH_URL', 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625')
 DEFAULT_TRAC_AUTH_USERNAME = getattr(settings, 'DEFAULT_TRAC_AUTH_USERNAME', 'Deploy')
@@ -34,9 +36,11 @@ SET_TRAC_LOGIN_AS_SUPERUSER = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", F
 
 USER_DATA_PATTERN = r"#\s+?(\w+):\s+?(\{.+\}?)"
 
+login_failed = Signal()
+
 class TracBackend(ModelBackend):
 
-    def check(self,request, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL,
+    def check(self, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL,
         tracUsername=DEFAULT_TRAC_AUTH_USERNAME, tracPassword=DEFAULT_TRAC_AUTH_PASSWORD):
         r = requests.get(tracAuthURL, auth=(tracUsername, tracPassword))
         content = r.text.strip()
@@ -58,7 +62,7 @@ class TracBackend(ModelBackend):
         return (False, None)
 
     def authenticate(self, request, username=None, password=None, **kwargs):
-        valid, info = self.check(request, username, password)
+        valid, info = self.check(username, password)
         if valid:
             try:
                 user = User.objects.get(username=username)
@@ -70,5 +74,6 @@ class TracBackend(ModelBackend):
                 user.save()
             return user
         else:
+            login_failed.send(sender=self.__class__, info=info)
             raise PermissionDenied(info)
         return None
